@@ -65,6 +65,8 @@
 #'   \code{\link{granovagg.ds}}, \code{\link{granovaGG}}
 #'
 #' @example demo/granovagg.ds.R
+#' @import stats
+#' @import utils
 #' @export
 #' @references Pruzek, R. M., & Helmreich, J. E. (2009). Enhancing Dependent Sample Analyses with Graphics. Journal of Statistics Education, 17(1), 21.
 #' @references Wickham, H. (2009). Ggplot2: Elegant Graphics for Data Analysis. New York: Springer.
@@ -91,6 +93,15 @@ granovagg.ds <- function(data       = NULL,
     return(data)
   }
 
+  FormatDataForPlotting <- function(dsp) {
+    return(
+      data.frame(
+        x_values = dsp$data[, 2],
+        y_values = dsp$data[, 1]
+      )
+    )
+  }
+
   CheckData <- function(data) {
     IsDataNull(data)
     IsDataInTwoColumnFormat(data)
@@ -150,7 +161,7 @@ granovagg.ds <- function(data       = NULL,
   }
 
   GetEffect <- function(dsp) {
-    return(GetXs(dsp$data) - GetYs(dsp$data))
+    return(GetXs(dsp$plotting_data) - GetYs(dsp$plotting_data))
   }
 
   GetTtest <- function(data, conf.level) {
@@ -164,16 +175,19 @@ granovagg.ds <- function(data       = NULL,
 
   GetStats <- function(dsp, conf.level) {
     ttest <- GetTtest(dsp$data, conf.level)
-    return(data.frame(lower.treatment.effect = as.numeric(ttest$conf.int[2]),
+    return(data.frame(lower.treatment.effect = as.numeric(ttest$conf.int[1]),
                       mean.treatment.effect  = as.numeric(ttest$estimate[1]),
-                      upper.treatment.effect = as.numeric(ttest$conf.int[1]),
+                      upper.treatment.effect = as.numeric(ttest$conf.int[2]),
                       t.statistic            = as.numeric(ttest$statistic[1])
                      )
           )
   }
 
   GetGraphicsParams <- function(dsp) {
-    .aggregate.data.range  <- c(range(GetXs(dsp$data)), range(GetYs(dsp$data)))
+    .aggregate.data.range  <- c(
+      range(dsp$plotting_data$x_values),
+      range(dsp$plotting_data$y_values)
+    )
     .extrema               <- c(max(.aggregate.data.range), min(.aggregate.data.range))
     .square.data.range     <- max(.extrema) - min(.extrema)
     .southwest.padding     <- (65/100) * .square.data.range
@@ -213,10 +227,10 @@ granovagg.ds <- function(data       = NULL,
   }
 
   GetCIBand <- function(dsp) {
-    return(data.frame(x.end = ((dsp$params$anchor + dsp$stats$lower.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
-                      y.end = ((dsp$params$anchor - dsp$stats$lower.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
-                      x     = ((dsp$params$anchor + dsp$stats$upper.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
-                      y     = ((dsp$params$anchor - dsp$stats$upper.treatment.effect) / 2) - 3 * (dsp$params$shadow.offset),
+    return(data.frame(x.end = ((dsp$params$anchor - dsp$stats$lower.treatment.effect) / 2) - (3 * (dsp$params$shadow.offset)),
+                      y.end = ((dsp$params$anchor + dsp$stats$lower.treatment.effect) / 2) - (3 * (dsp$params$shadow.offset)),
+                      x     = ((dsp$params$anchor - dsp$stats$upper.treatment.effect) / 2) - (3 * (dsp$params$shadow.offset)),
+                      y     = ((dsp$params$anchor + dsp$stats$upper.treatment.effect) / 2) - (3 * (dsp$params$shadow.offset)),
                       color = factor(paste(100 * conf.level, "% CI", " (t = ", round(dsp$stats$t.statistic, digits = 2), ")", sep =""))
                      )
           )
@@ -224,7 +238,7 @@ granovagg.ds <- function(data       = NULL,
   }
 
   GetTreatmentLine <- function(dsp) {
-    return(data.frame(intercept = -dsp$stats$mean.treatment.effect,
+    return(data.frame(intercept = dsp$stats$mean.treatment.effect,
                       slope     = 1,
                       color     = factor(paste("Mean Diff. =", round(dsp$stats$mean.treatment.effect, digits = 2)))
                      )
@@ -248,8 +262,8 @@ granovagg.ds <- function(data       = NULL,
   }
 
   GetTrails <- function(dsp) {
-    return(data.frame(x.trail.start = GetXs(dsp$data),
-                      y.trail.start = GetYs(dsp$data),
+    return(data.frame(x.trail.start = dsp$plotting_data$x_values,
+                      y.trail.start = dsp$plotting_data$y_values,
                       x.trail.end   = GetXs(dsp$shadow),
                       y.trail.end   = GetYs(dsp$shadow)
                      )
@@ -329,6 +343,7 @@ granovagg.ds <- function(data       = NULL,
   }
 
   dsp                <- list(data = GetData(data))
+  dsp$plotting_data  <- FormatDataForPlotting(dsp)
   dsp$effect         <- GetEffect(dsp)
   dsp$stats          <- GetStats(dsp, conf.level)
   dsp$t.test         <- GetTtest(dsp$data, conf.level)
@@ -352,9 +367,11 @@ granovagg.ds <- function(data       = NULL,
   InitializeGgplot <- function(dsp) {
     return(
       ggplot(
-        aes_string(x = dsp$data[1],
-                   y = dsp$data[2]
-        ), data = dsp$data
+        aes_string(
+          x = "x_values",
+          y = "y_values"
+        ),
+        data = dsp$plotting_data
       )
     )
   }
@@ -367,7 +384,7 @@ granovagg.ds <- function(data       = NULL,
           slope     = "slope",
           color     = "color"
         ),
-        lpha    = 0.5,
+        alpha    = 0.5,
         size     = I(1),
         linetype = "dashed",
         data     = dsp$treatment.line
@@ -378,6 +395,11 @@ granovagg.ds <- function(data       = NULL,
   RawData <- function(dsp) {
     return(
       geom_point(
+        aes_string(
+          x = "x_values",
+          y = "y_values"
+        ),
+        data = dsp$plotting_data,
         size = dsp$params$point.size
       )
     )
@@ -430,7 +452,7 @@ granovagg.ds <- function(data       = NULL,
         alpha = 1/3,
         color = dsp$colors$rugplot,
         sides = "tr", # top and right sides
-        data  = dsp$data
+        data  = dsp$plotting_data
       )
     )
   }
@@ -438,7 +460,7 @@ granovagg.ds <- function(data       = NULL,
   XMeanLine <- function(dsp) {
     return(
       geom_vline(
-        xintercept = mean(GetXs(dsp$data)),
+        xintercept = mean(dsp$data[, 2]),
         color      = dsp$colors$mean.line,
         size       = dsp$params$mean.line.size,
         linetype   = "dashed",
@@ -450,7 +472,7 @@ granovagg.ds <- function(data       = NULL,
   YMeanLine <- function(dsp)  {
     return(
       geom_hline(
-        yintercept = mean(GetYs(dsp$data)),
+        yintercept = mean(dsp$data[, 1]),
         color      = dsp$colors$mean.line,
         size       = dsp$params$mean.line.size,
         linetype   = "dashed",
@@ -571,7 +593,7 @@ granovagg.ds <- function(data       = NULL,
   p <- p + Shadows(dsp)
   p <- p + Trails(dsp)
   p <- p + RawData(dsp)
-  p <- p + Theme(plot.theme)
+  # p <- p + Theme(plot.theme)
   p <- p + IdentityLine()
   p <- p + RugPlot(dsp)
   p <- p + Crossbow(dsp)
